{config, ...}: {
  home-manager.useUserPackages = true;
  home-manager.useGlobalPkgs = true;
  home-manager.users.jas = {pkgs, ...}: {
    home.packages = with pkgs; [
      diff-so-fancy
      gcc
      glow
      gnumake
      gum
      httpie
      hyperfine
      pass
      python3Full
      rustup
      shellcheck
      shfmt
      stow
      tealdeer
      w3m
      zsh-nix-shell
    ];

    home = {
      username = "jas";
      homeDirectory = "/home/jas";
      stateVersion = "23.05";
    };

    programs.git = {
      enable = true;
      userEmail = "23226432+hyperreal64@users.noreply.github.com";
      userName = "Jeffrey Serio";
      extraConfig = {
        safe.directory = "/etc/nixos";
        core = {
          editor = "vim";
          pager = "diff-so-fancy | less --tabs=4 -RFX";
        };
        init.defaultBranch = "main";
        pull.rebase = true;
      };
    };

    programs.gpg = {
      enable = true;
      settings = {
        default-key = "0x9129BD07C3509CED";
        no-emit-version = true;
        no-comments = true;
        display-charset = "utf-8";
        keyid-format = "0xlong";
        with-fingerprint = true;
        use-agent = true;
      };
    };

    services.gpg-agent = {
      enable = true;
      defaultCacheTtl = 1800;
      enableSshSupport = true;
    };

    programs.fzf = {
      enable = true;
      defaultCommand = "fd --type f";
    };

    programs.bat = {
      enable = true;
      config = {
        pager = "less -FR";
        theme = "Catppuccin-Mocha";
      };
    };

    manual.json.enable = true;
  };
}
